==> maplink-fabric-4.0.1-1.18.2-sources.jar: de/the_build_craft/maplink/common/wrappers/Text.java <==
/*
 *    This file is part of the Map Link mod
 *    licensed under the GNU GPL v3 License.
 *
 *    Copyright (C) 2024 - 2025  Leander Knüttel and contributors
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.the_build_craft.maplink.common.wrappers;

import net.minecraft.class_2561;
import net.minecraft.class_2585;
import net.minecraft.class_2588;
import net.minecraft.class_5250;
import net.minecraft.network.chat.*;

/**
 * @author Leander Knüttel
 * @version 03.07.2024
 */
public class Text {
    #if MC_VER > MC_1_18_2
    public static class_5250 literal(String string) {
        return class_2561.literal(string);
    }

    public static class_5250 translatable(String translateKey) {
        return class_2561.translatable(translateKey);
    }

    #else
    public static class_5250 literal(String string) {
        return new class_2585(string);
    }

    public static class_5250 translatable(String translateKey) {
        return new class_2588(translateKey);
    }
    #endif
}

==> maplink-fabric-4.0.2-1.21.9-1.21.10-sources.jar: de/the_build_craft/maplink/common/wrappers/Text.java <==
/*
 *    This file is part of the Map Link mod
 *    licensed under the GNU GPL v3 License.
 *
 *    Copyright (C) 2024 - 2025  Leander Knüttel and contributors
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package de.the_build_craft.maplink.common.wrappers;

import net.minecraft.class_2561;
import net.minecraft.class_5250;
import net.minecraft.network.chat.*;

/**
 * @author Leander Knüttel
 * @version 03.07.2024
 */
public class Text {
    #if MC_VER > MC_1_18_2
    public static class_5250 literal(String string) {
        return class_2561.method_43470(string);
    }

    public static class_5250 translatable(String translateKey) {
        return class_2561.method_43471(translateKey);
    }

    #else
    public static class_5250 literal(String string) {
        return new TextComponent(string);
    }

    public static class_5250 translatable(String translateKey) {
        return new TranslatableComponent(translateKey);
    }
    #endif
}
